@@ -29,13 +29,16 @@ void     meta_display_init_keys             (MetaDisplay *display);
 void     meta_display_shutdown_keys         (MetaDisplay *display);
 void     meta_screen_grab_keys              (MetaScreen  *screen);
 void     meta_screen_ungrab_keys            (MetaScreen  *screen);
-gboolean meta_screen_grab_all_keys          (MetaScreen *screen);
-void     meta_screen_ungrab_all_keys        (MetaScreen *screen);
+gboolean meta_screen_grab_all_keys          (MetaScreen *screen,
+                                             Time timestamp);
+void     meta_screen_ungrab_all_keys        (MetaScreen *screen, 
+                                             Time timestamp);
 void     meta_window_grab_keys              (MetaWindow  *window);
 void     meta_window_ungrab_keys            (MetaWindow  *window);
 gboolean meta_window_grab_all_keys          (MetaWindow  *window,
                                              Time         timestamp);
-void     meta_window_ungrab_all_keys        (MetaWindow  *window);
+void     meta_window_ungrab_all_keys        (MetaWindow  *window,
+                                             Time         timestamp);
 void     meta_display_process_key_event     (MetaDisplay *display,
                                              MetaWindow  *window,
                                              XEvent      *event);
